﻿using AsmodeeDigital.PlayReal.Plugin.Domain.GameState;
using ProtoBuf;
using System;

namespace AsmodeeDigital.PlayReal.Samples.Domain.GameState.Events
{
    /// <summary>
    /// Event of the game initialization. Must be the first event of hte game state
    /// </summary>
    [ProtoContract, Serializable]
    public class GameInitialized : IEvent
    {
        /// <summary>
        /// Player local ID
        /// </summary>
        [ProtoMember(1)]
        public int PlayerLocalID { get; set; }

        /// <summary>
        /// UTC time
        /// </summary>
        [ProtoMember(2)]
        public long Time { get; set; }

        /// <summary>
        /// Seed for the Random Number Generator
        /// </summary>
        [ProtoMember(3)]
        public int Seed;

        /// <summary>
        /// Count of players in the game
        /// </summary>
        [ProtoMember(4)]
        public int CountPlayers = 0;

        public GameInitialized()
        {
        }

        public GameInitialized(int playerLocalID, int seed, int countPlayers)
        {
            PlayerLocalID = playerLocalID;
            Seed = seed;
            CountPlayers = countPlayers;

            Time = DateTime.Now.Ticks;
        }
    }
}
